==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/df/d20/window__func_8h.js <==
var window__func_8h =
[
    [ "ChangeWindowOwner", "df/d20/window__func_8h.html#a918eb2842204b21d1e95cb3ae4688a03", null ],
    [ "DeleteAllNonVitalWindows", "df/d20/window__func_8h.html#a4c7623134b376391f9a6bd8ffa93335c", null ],
    [ "DeleteConstructionWindows", "df/d20/window__func_8h.html#a7a70366e0a88b674fd3ae03733f7117a", null ],
    [ "DeleteNonVitalWindows", "df/d20/window__func_8h.html#ab24b4302fd0acce9a20dc4d5463193e0", null ],
    [ "DeleteWindowByClass", "df/d20/window__func_8h.html#aa1c99e5603ae790bc2ba5916832a4aaf", null ],
    [ "DeleteWindowById", "df/d20/window__func_8h.html#a3aa4f361b59f4cb1223aaa7397ac73c3", null ],
    [ "EditBoxInGlobalFocus", "df/d20/window__func_8h.html#aa6d3fc78c16b593a82f97e78c23abc04", null ],
    [ "FindWindowByClass", "df/d20/window__func_8h.html#a46bebae08cad5acc243c83f2def9a7ac", null ],
    [ "FindWindowById", "df/d20/window__func_8h.html#a40332861cd28b86f94ab1d97f8a2b9ba", null ],
    [ "GetCaretPosition", "df/d20/window__func_8h.html#af3b52f17047117fde8567a9533a9ed81", null ],
    [ "GetMainViewBottom", "df/d20/window__func_8h.html#a8ad1fb6233068edab6a4d999dfcb389e", null ],
    [ "GetMainViewTop", "df/d20/window__func_8h.html#a754b84b9002894c9ea382cbfba76d586", null ],
    [ "HideVitalWindows", "df/d20/window__func_8h.html#aa8f3b590cd170c1cf276d567b624f4d9", null ],
    [ "InitWindowSystem", "df/d20/window__func_8h.html#af8bed9a47bd4bc55bc5bb82911814612", null ],
    [ "InputLoop", "df/d20/window__func_8h.html#a252c2ffa87710df5b835b6febb76097d", null ],
    [ "InvalidateWindowClassesData", "df/d20/window__func_8h.html#a68a0c145e0f623c33dd1e7fa0e680f5d", null ],
    [ "InvalidateWindowData", "df/d20/window__func_8h.html#aa8bda40d8104cff94c9911306d4df046", null ],
    [ "PositionMainToolbar", "df/d20/window__func_8h.html#a2ad4f9f4c01362e46eca6afb3013ad7d", null ],
    [ "PositionNetworkChatWindow", "df/d20/window__func_8h.html#a3612b9d76bd8f3702b6d135d76839cf2", null ],
    [ "PositionNewsMessage", "df/d20/window__func_8h.html#a83c6a47d3352cd14a251d12cc0b8d05f", null ],
    [ "PositionStatusbar", "df/d20/window__func_8h.html#a005e7a36aa4fe3c6c6b57ff9df60b013", null ],
    [ "ReInitAllWindows", "df/d20/window__func_8h.html#a37e9d076656bfdf6f585b0e3e58ff36e", null ],
    [ "ResetWindowSystem", "df/d20/window__func_8h.html#aa5e701965df99f5d4dfe82b92ac14cd8", null ],
    [ "ResizeWindow", "df/d20/window__func_8h.html#a8249c7b08953395a7159b9ade651b01c", null ],
    [ "SetupColoursAndInitialWindow", "df/d20/window__func_8h.html#a55d3768f8fd70e0d8774f72cd07cb3c8", null ],
    [ "SetWindowClassesDirty", "df/d20/window__func_8h.html#a950bfd34932efababe9a14ec760bc555", null ],
    [ "SetWindowDirty", "df/d20/window__func_8h.html#afd86115e33fa507f6a0228f244d4e954", null ],
    [ "SetWindowWidgetDirty", "df/d20/window__func_8h.html#aabcea5b189208aa784e6f0e01547024b", null ],
    [ "ShowVitalWindows", "df/d20/window__func_8h.html#a09240eb994f64bbd4dc0deef77da9263", null ],
    [ "UnInitWindowSystem", "df/d20/window__func_8h.html#af784992c5853a3238d7ee12c65004d4d", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/df/d20/window__func_8h.js <==
var window__func_8h =
[
    [ "ChangeWindowOwner", "df/d20/window__func_8h.html#a918eb2842204b21d1e95cb3ae4688a03", null ],
    [ "DeleteAllMessages", "df/d20/window__func_8h.html#a7242560246471268886bac2744b5d688", null ],
    [ "DeleteAllNonVitalWindows", "df/d20/window__func_8h.html#a4c7623134b376391f9a6bd8ffa93335c", null ],
    [ "DeleteConstructionWindows", "df/d20/window__func_8h.html#a7a70366e0a88b674fd3ae03733f7117a", null ],
    [ "DeleteNonVitalWindows", "df/d20/window__func_8h.html#ab24b4302fd0acce9a20dc4d5463193e0", null ],
    [ "DeleteWindowByClass", "df/d20/window__func_8h.html#aa1c99e5603ae790bc2ba5916832a4aaf", null ],
    [ "DeleteWindowById", "df/d20/window__func_8h.html#a3aa4f361b59f4cb1223aaa7397ac73c3", null ],
    [ "EditBoxInGlobalFocus", "df/d20/window__func_8h.html#aa6d3fc78c16b593a82f97e78c23abc04", null ],
    [ "FindWindowByClass", "df/d20/window__func_8h.html#a46bebae08cad5acc243c83f2def9a7ac", null ],
    [ "FindWindowById", "df/d20/window__func_8h.html#a40332861cd28b86f94ab1d97f8a2b9ba", null ],
    [ "FocusedWindowIsConsole", "df/d20/window__func_8h.html#aa5d37fcac630be1814ebf7ee44d5a4c0", null ],
    [ "GetCaretPosition", "df/d20/window__func_8h.html#af3b52f17047117fde8567a9533a9ed81", null ],
    [ "GetMainViewBottom", "df/d20/window__func_8h.html#a8ad1fb6233068edab6a4d999dfcb389e", null ],
    [ "GetMainViewTop", "df/d20/window__func_8h.html#a754b84b9002894c9ea382cbfba76d586", null ],
    [ "HideVitalWindows", "df/d20/window__func_8h.html#aa8f3b590cd170c1cf276d567b624f4d9", null ],
    [ "InitWindowSystem", "df/d20/window__func_8h.html#af8bed9a47bd4bc55bc5bb82911814612", null ],
    [ "InputLoop", "df/d20/window__func_8h.html#a252c2ffa87710df5b835b6febb76097d", null ],
    [ "InvalidateWindowClassesData", "df/d20/window__func_8h.html#a68a0c145e0f623c33dd1e7fa0e680f5d", null ],
    [ "InvalidateWindowData", "df/d20/window__func_8h.html#aa8bda40d8104cff94c9911306d4df046", null ],
    [ "PositionMainToolbar", "df/d20/window__func_8h.html#a2ad4f9f4c01362e46eca6afb3013ad7d", null ],
    [ "PositionNetworkChatWindow", "df/d20/window__func_8h.html#a3612b9d76bd8f3702b6d135d76839cf2", null ],
    [ "PositionNewsMessage", "df/d20/window__func_8h.html#a83c6a47d3352cd14a251d12cc0b8d05f", null ],
    [ "PositionStatusbar", "df/d20/window__func_8h.html#a005e7a36aa4fe3c6c6b57ff9df60b013", null ],
    [ "ReInitAllWindows", "df/d20/window__func_8h.html#a37e9d076656bfdf6f585b0e3e58ff36e", null ],
    [ "ResetWindowSystem", "df/d20/window__func_8h.html#aa5e701965df99f5d4dfe82b92ac14cd8", null ],
    [ "ResizeWindow", "df/d20/window__func_8h.html#a8249c7b08953395a7159b9ade651b01c", null ],
    [ "SetupColoursAndInitialWindow", "df/d20/window__func_8h.html#a55d3768f8fd70e0d8774f72cd07cb3c8", null ],
    [ "SetWindowClassesDirty", "df/d20/window__func_8h.html#a950bfd34932efababe9a14ec760bc555", null ],
    [ "SetWindowDirty", "df/d20/window__func_8h.html#afd86115e33fa507f6a0228f244d4e954", null ],
    [ "SetWindowWidgetDirty", "df/d20/window__func_8h.html#aabcea5b189208aa784e6f0e01547024b", null ],
    [ "ShowVitalWindows", "df/d20/window__func_8h.html#a09240eb994f64bbd4dc0deef77da9263", null ],
    [ "UnInitWindowSystem", "df/d20/window__func_8h.html#af784992c5853a3238d7ee12c65004d4d", null ]
];
